@@ -37,6 +37,7 @@ use strict;
 use warnings;
 use App::CELL qw( $CELL $log $meta $site );
 use Data::Dumper;
+use App::Dochazka::REST::Model::Activity qw( code_by_aid );
 use App::Dochazka::REST::Model::Lock qw( count_locks_in_tsrange );
 use App::Dochazka::REST::Model::Shared qw( 
     canonicalize_tsrange 
@@ -47,6 +48,13 @@ use App::Dochazka::REST::Model::Shared qw(
     select_single
     tsrange_intersection
 );
+use App::Dochazka::REST::Util::Date qw(
+    calculate_hours
+    tsrange_to_dates_and_times
+);
+use App::Dochazka::REST::Util::Holiday qw(
+    holidays_and_weekends
+);
 use Params::Validate qw( :all );
 
 # we get 'spawn', 'reset', and accessors from parent
@@ -135,6 +143,7 @@ use Exporter qw( import );
 our @EXPORT_OK = qw( 
     delete_intervals_by_eid_and_tsrange
     fetch_intervals_by_eid_and_tsrange
+    generate_interval_summary
     iid_exists 
 );
 
@@ -411,7 +420,6 @@ sub delete_intervals_by_eid_and_tsrange {
     return $CELL->status_err( 'DOCHAZKA_INTERVAL_DELETE_LIMIT_EXCEEDED', args => [ $count ] )
         if $count >= $site->DOCHAZKA_INTERVAL_DELETE_LIMIT;
     
-    # hmm, can we use select_single with a DELETE statement?
     return cud_generic(
         conn => $conn,
         eid => $eid,
@@ -421,6 +429,72 @@ sub delete_intervals_by_eid_and_tsrange {
 }
 
 
+=head2 generate_interval_summary
+
+Given DBIx::Connector object, EID, and tsrange, generate a hash keyed on
+dates (YYYY-MM-DD) in the range. The value of each key/date is another 
+hash keyed on activity codes. For each activity code the value is the
+total number of hours spent by the employee doing that activity on the day
+in question.
+
+The interval must start and end on a day boundary (i.e. 00:00 or 24:00)
+and partial intervals are treated the same as whole intervals.
+
+=cut
+
+sub generate_interval_summary {
+    my ( $conn, $eid, $tsrange ) = validate_pos( @_,
+        { isa => 'DBIx::Connector' },
+        { type => SCALAR },
+        { type => SCALAR },
+    );
+
+    my $status = canonicalize_tsrange( $conn, $tsrange );
+    return $status unless $status->ok;
+    my $canon_tsrange = $status->payload;
+    $log->debug( "generate_interval_summary: $canon_tsrange" );
+
+    # convert canonicalized tsrange into begin, end dates
+    $status = tsrange_to_dates_and_times( $canon_tsrange );
+    return $status unless $status->ok;
+
+    # extract the beginning/ending dates/times
+    my $pl = $status->payload;
+    my $begin_date = $pl->{begin}->[0];
+    my $begin_time = $pl->{begin}->[1];
+    my $end_date = $pl->{end}->[0];
+    my $end_time = $pl->{end}->[1];
+
+    # interval must begin and end at 00:00/24:00,
+    # otherwise no game
+    return $CELL->status_err( 'DISPATCH_SUMMARY_ILLEGAL_TSRANGE' ) unless
+        ( $begin_time eq '00:00' or $begin_time eq '24:00' ) and 
+        ( $end_time eq '00:00' or $end_time eq '24:00' );
+
+    # get list of dates in range
+    my $date_hash = holidays_and_weekends( begin => $begin_date, end => $end_date );
+
+    # get intervals for each date
+    foreach my $date ( keys %$date_hash ) {
+        my $status = fetch_intervals_by_eid_and_tsrange( 
+            $conn, 
+            $eid, 
+            "[ $date 00:00, $date 24:00 )",
+        );
+        if ( $status->ok and $status->code eq 'DISPATCH_RECORDS_FOUND' ) {
+            map { $date_hash
+                      ->{ $date }
+                      ->{ code_by_aid( $conn, $_->aid ) }
+                      ->{hours} += calculate_hours( $_->intvl ) } 
+                ( @{ $status->payload } );
+        }
+    }
+
+    return $CELL->status_ok( 'DOCHAZKA_INTERVAL_SUMMARY_OK', payload => $date_hash );
+}
+
+
+
 =head1 AUTHOR
 
 Nathan Cutler, C<< <presnypreklad@gmail.com> >>
